@@ -64,7 +64,7 @@ class Drip(models.Model):
         )
         return drip
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
 
@@ -131,11 +131,16 @@ class QuerySetRule(models.Model):
     )
 
     method_type = models.CharField(
-        max_length=12, default='filter', choices=METHOD_TYPES)
+        max_length=12,
+        default='filter',
+        choices=METHOD_TYPES,
+    )
     field_name = models.CharField(
-        max_length=128, verbose_name='Field name of User')
+        max_length=128, verbose_name='Field name of User'
+    )
     lookup_type = models.CharField(
-        max_length=12, default='exact', choices=LOOKUP_TYPES)
+        max_length=12, default='exact', choices=LOOKUP_TYPES
+    )
 
     field_value = models.CharField(
         max_length=255,
@@ -151,14 +156,18 @@ class QuerySetRule(models.Model):
             self.apply(User.objects.all())
         except Exception as e:
             raise ValidationError(
-                '%s raised trying to apply rule: %s' % (type(e).__name__, e))
+                '{type_name} raised trying to apply rule: {error}'.format(
+                    type_name=type(e).__name__,
+                    error=str(e),
+                )
+            )
 
     @property
     def annotated_field_name(self):
         field_name = self.field_name
         if field_name.endswith('__count'):
             agg, _, _ = field_name.rpartition('__')
-            field_name = 'num_%s' % agg.replace('__', '_')
+            field_name = 'num_{agg}'.format(agg=agg.replace('__', '_'))
 
         return field_name
 
